"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.genCommon = void 0;

var _path = require("path");

var _babelPresetBase = require("@modern-js/babel-preset-base");

var _utils = require("@modern-js/utils");

var _utils2 = require("./utils");

const prepareEnvOptions = options => {
  const {
    useBuiltIns,
    modules,
    useModern
  } = options;
  const envOptions = {
    useBuiltIns,
    modules,
    exclude: ['transform-typeof-symbol'],
    corejs: useBuiltIns ? {
      version: (0, _utils2.getCoreJsVersion)(),
      proposals: true
    } : undefined
  };

  if (useModern) {
    envOptions.targets = {
      esmodules: true
    };
    envOptions.modules = false;
    envOptions.bugfixes = true;
  }

  return envOptions;
};

const genCommon = options => {
  const {
    lodash: lodashOptions,
    target,
    metaName,
    appDirectory,
    useLegacyDecorators,
    modules,
    styledComponents,
    useTsLoader,
    overrideBrowserslist
  } = options;
  const useSSR = target === 'server';
  const envOptions = prepareEnvOptions(options);
  const chain = (0, _babelPresetBase.createBabelChain)();
  const baseConfigChain = (0, _babelPresetBase.getBaseBabelChain)({
    appDirectory,
    useTsLoader,
    runEnvironments: (0, _utils.isTest)() || target === 'server' ? 'node' : 'browsers',
    // https://babeljs.io/docs/en/babel-preset-react#runtime
    jsxTransformRuntime: (0, _utils2.isBeyondReact17)(appDirectory) ? 'automatic' : 'classic',
    presets: {
      // 与内部的preset-env配置合并
      envOptions,
      typescriptOptions: {
        allExtensions: true,
        allowDeclareFields: true,
        isTSX: true
      },
      reactOptions: {
        // Adds component stack to warning messages
        // Adds __self attribute to JSX which React will use for some warnings
        development: (0, _utils.isDev)() || (0, _utils.isTest)(),
        // Will use the native built-in instead of trying to polyfill
        // behavior for any plugins that require one.
        useBuiltIns: true,
        // 原来配置中没有配置这个，默认为false，而 base config里有配置
        useSpread: false
      }
    },
    plugins: {
      lodashOptions,
      import: {
        antd: {
          libraryDirectory: useSSR ? 'lib' : 'es'
        }
      },
      transformRuntime: {
        // version, regenerator 在 base config 里已配置
        // https://babeljs.io/docs/en/babel-plugin-transform-runtime#useesmodules
        // We should turn this on once the lowest version of Node LTS
        // supports ES Modules.
        useESModules: !modules,
        helpers: target === 'client' && !(0, _utils.isTest)()
      },
      transformReactRemovePropTypes: (0, _utils.isProd)() ? {// 内部默认 removeImport: true,
      } : false,
      styledComponentsOptions: styledComponents
    },
    syntax: 'es5',
    useLegacyDecorators,
    overrideBrowserslist
  });
  chain.plugin('built-in/babel-plugin-lock-corejs-version').use((0, _path.join)(__dirname, './built-in/babel-plugin-lock-corejs-version'), [{
    metaName
  }]);
  chain.plugin('./built-in/babel-plugin-ssr-loader-id').use((0, _path.join)(__dirname, './built-in/babel-plugin-ssr-loader-id'));
  return chain.merge(baseConfigChain);
};

exports.genCommon = genCommon;